@@ -64,6 +64,10 @@ class KubeCluster(Cluster):
         List of environment variables to pass to worker pod.
         Can be a list of dicts using the same structure as k8s envs
         or a single dictionary of key/value pairs
+    worker_command: List[str] | str
+        The command to use when starting the worker.
+        If command consists of multiple words it should be passed as a list of strings.
+        Defaults to ``"dask-worker"``.
     auth: List[ClusterAuth] (optional)
         Configuration methods to attempt in order.  Defaults to
         ``[InCluster(), KubeConfig()]``.
@@ -127,18 +131,21 @@ class KubeCluster(Cluster):
         n_workers=3,
         resources={},
         env=[],
+        worker_command="dask-worker",
         auth=ClusterAuth.DEFAULT,
         port_forward_cluster_ip=None,
         create_mode=CreateMode.CREATE_OR_CONNECT,
         shutdown_on_close=None,
         **kwargs,
     ):
-        self.name = name
         self.namespace = namespace or namespace_default()
         self.image = image
         self.n_workers = n_workers
         self.resources = resources
         self.env = env
+        self.worker_command = worker_command
+        if isinstance(self.worker_command, str):
+            self.worker_command = self.worker_command.split(" ")
         self.auth = auth
         self.port_forward_cluster_ip = port_forward_cluster_ip
         self.create_mode = create_mode
@@ -146,7 +153,7 @@ class KubeCluster(Cluster):
 
         self._instances.add(self)
 
-        super().__init__(**kwargs)
+        super().__init__(name=name, **kwargs)
         if not self.asynchronous:
             self._loop_runner.start()
             self.sync(self._start)
@@ -224,14 +231,17 @@ class KubeCluster(Cluster):
         async with kubernetes.client.api_client.ApiClient() as api_client:
             core_api = kubernetes.client.CoreV1Api(api_client)
             cluster_spec = await self._get_cluster()
-            self.image = cluster_spec["spec"]["worker"]["spec"]["containers"][0][
-                "image"
-            ]
+            container_spec = cluster_spec["spec"]["worker"]["spec"]["containers"][0]
+            self.image = container_spec["image"]
             self.n_workers = cluster_spec["spec"]["worker"]["replicas"]
-            self.resources = cluster_spec["spec"]["worker"]["spec"]["containers"][0][
-                "resources"
-            ]
-            self.env = cluster_spec["spec"]["worker"]["spec"]["containers"][0]["env"]
+            if "resources" in container_spec:
+                self.resources = container_spec["resources"]
+            else:
+                self.resources = None
+            if "env" in container_spec:
+                self.env = container_spec["env"]
+            else:
+                self.env = {}
             service_name = f'{cluster_spec["metadata"]["name"]}-service'
             await wait_for_scheduler(self.cluster_name, self.namespace)
             await wait_for_service(core_api, service_name, self.namespace)
@@ -533,6 +543,8 @@ class KubeCluster(Cluster):
             # If they gave us a list, assume its a list of dicts and already ready to go
             env = self.env
 
+        args = self.worker_command + ["--name", "$(DASK_WORKER_NAME)"]
+
         return {
             "cluster": self.cluster_name,
             "replicas": self.n_workers,
@@ -541,11 +553,7 @@ class KubeCluster(Cluster):
                     {
                         "name": "worker",
                         "image": self.image,
-                        "args": [
-                            "dask-worker",
-                            "--name",
-                            "$(DASK_WORKER_NAME)",
-                        ],
+                        "args": args,
                         "env": env,
                         "resources": self.resources,
                     }
